@@ -1,6 +1,7 @@
 import json
 
 from grebble_flow.grpc.processor import processor_pb2_grpc, processor_pb2
+from grebble_flow.helpers.converter import grebble_converter
 from grebble_flow.managment.manager import FlowManager
 
 
@@ -19,7 +20,7 @@ class ProcessorService(processor_pb2_grpc.ProcessorServicer):
             pass
         for item in self.flow_manager.run(flow_name, data):
             yield processor_pb2.FlowResponse(
-                jsonString=json.dumps(item), streamEnd=False
+                jsonString=json.dumps(item, default=grebble_converter), streamEnd=False
             )
 
         yield processor_pb2.FlowResponse(jsonString="", streamEnd=True)
